Function polylineffi::drop_cstring
source · #[no_mangle]
pub unsafe extern "C" fn drop_cstring(p: *mut c_char)Expand description
Free CString memory which Rust has allocated across the FFI boundary
Safety
This function is unsafe because it accesses a raw pointer which could contain arbitrary data