drop_float_array

Function drop_float_array 

#[unsafe(no_mangle)]
pub extern "C" fn drop_float_array(_: InternalArray)
Free Array memory which Rust has allocated across the FFI boundary

Safety

This function is unsafe because it accesses a raw pointer which could contain arbitrary data