Function polylineffi::drop_float_array
source · #[no_mangle]
pub extern "C" fn drop_float_array(_: InternalArray)Expand description
Free Array memory which Rust has allocated across the FFI boundary
Safety
This function is unsafe because it accesses a raw pointer which could contain arbitrary data